@@ -307,6 +307,10 @@ static chop_error_t chk_block_fetch (chop_block_fetcher_t *,
 				     chop_block_store_t *,
 				     chop_buffer_t *,
 				     size_t *);
+static chop_error_t chk_block_exists (chop_block_fetcher_t *,
+				      const chop_index_handle_t *,
+				      chop_block_store_t *,
+				      int *);
 
 static chop_error_t
 cbf_ctor (chop_object_t *object, const chop_class_t *class)
@@ -315,6 +319,7 @@ cbf_ctor (chop_object_t *object, const chop_class_t *class)
 
   fetcher = (chop_chk_block_fetcher_t *) object;
   fetcher->block_fetcher.fetch_block = chk_block_fetch;
+  fetcher->block_fetcher.block_exists = chk_block_exists;
   fetcher->block_fetcher.index_handle_class = &chop_chk_index_handle_class;
 
   fetcher->cipher_handle = CHOP_CIPHER_HANDLE_NIL;
@@ -508,6 +513,26 @@ chop_chk_block_fetcher_log (chop_block_fetcher_t *fetcher)
   return (&cbf->log);
 }
 
+static chop_error_t
+chk_block_exists (chop_block_fetcher_t *block_fetcher,
+		  const chop_index_handle_t *index,
+		  chop_block_store_t *store,
+		  int *exists)
+{
+  chop_block_key_t key;
+  chop_chk_index_handle_t *handle;
+
+  if (!chop_object_is_a ((chop_object_t *) index,
+			 &chop_chk_index_handle_class))
+    return CHOP_INVALID_ARG;
+
+  handle = (chop_chk_index_handle_t *) index;
+  chop_block_key_init (&key, handle->block_id, handle->block_id_size,
+		       NULL, NULL);
+
+  return chop_store_block_exists (store, &key, exists);
+}
+
 static chop_error_t
 chk_block_fetch (chop_block_fetcher_t *block_fetcher,
 		 const chop_index_handle_t *index,
@@ -736,7 +761,39 @@ static chop_error_t
 cbi_serialize (const chop_object_t *object, chop_serial_method_t method,
 	       chop_buffer_t *buffer)
 {
-  return CHOP_ERR_NOT_IMPL;
+  chop_chk_block_indexer_t *indexer;
+
+  indexer = (chop_chk_block_indexer_t *) object;
+  switch (method)
+    {
+    case CHOP_SERIAL_ASCII:
+      {
+	chop_cipher_handle_t cipher;
+	const char *algo_name, *mode_name, *key_hash_name, *block_id_hash_name;
+
+	cipher = indexer->cipher_handle;
+	algo_name = chop_cipher_algo_name (chop_cipher_algorithm (cipher));
+	mode_name = chop_cipher_mode_name (chop_cipher_mode (cipher));
+	key_hash_name = chop_hash_method_name (indexer->key_hash_method);
+	block_id_hash_name = chop_hash_method_name (indexer->block_id_hash_method);
+
+	chop_buffer_push (buffer, algo_name, strlen (algo_name));
+	chop_buffer_append (buffer, ",", 1);
+	chop_buffer_append (buffer, mode_name, strlen (mode_name));
+	chop_buffer_append (buffer, ",", 1);
+	chop_buffer_append (buffer, key_hash_name, strlen (key_hash_name));
+	chop_buffer_append (buffer, ",", 1);
+	chop_buffer_append (buffer, block_id_hash_name,
+			    strlen (block_id_hash_name) + 1);
+
+	break;
+      }
+
+    default:
+      return CHOP_ERR_NOT_IMPL;
+    }
+
+  return 0;
 }
 
 static chop_error_t
@@ -759,13 +816,15 @@ cbi_deserialize (const char *buffer, size_t size, chop_serial_method_t method,
 	/* The user-visible serialization format is as follows:
 	   CIPHER,CIPHER-MODE,KEY-HASH,BLOCK-ID-HASH.  So, for instance, the
 	   following is a valid combination: "blowfish,cbc,sha1,sha1".  */
-	const char *end;
+	const char *end, *start;
 	char *comma;
 	char *algo_name, *mode_name, *key_hash_name, *block_id_hash_name;
 	chop_cipher_algo_t algo;
 	chop_cipher_mode_t mode;
 	chop_hash_method_t key_hash_method, block_id_hash_method;
 
+	start = buffer;
+
 #define FETCH_NAME(_name)				\
     comma = memchr (buffer, ',', size - *bytes_read);	\
     if (!comma)						\
@@ -785,7 +844,7 @@ cbi_deserialize (const char *buffer, size_t size, chop_serial_method_t method,
 
 	/* The last one needs to be treated specially.  */
 	for (end = comma + 1;
-	     *end && isalnum (*end);
+	     *end && isalnum (*end) && end - start < size;
 	     end++);
 	block_id_hash_name = alloca (end - comma);
 	strncpy (block_id_hash_name, comma + 1, end - comma - 1);
